@@ -749,7 +749,7 @@ class MainW(QtGui.QMainWindow):
         if self.autobtn.isChecked():
             self.saturation = [[0,255] for n in range(self.NZ)]
         self.currentZ = 0
-        self.flows = [[],[],[],[]]
+        self.flows = [[],[],[]]
         self.stack = np.zeros((1,self.Ly,self.Lx,3))
         # masks matrix
         self.layers = 0*np.ones((1,self.Ly,self.Lx,4), np.uint8)
@@ -917,7 +917,7 @@ class MainW(QtGui.QMainWindow):
             self.img.setLevels(self.saturation[self.currentZ])
         else:
             image = np.zeros((self.Ly,self.Lx), np.uint8)
-            if hasattr(self, 'flows') and len(self.flows[self.view-1])>0:
+            if len(self.flows)>=self.view-1 and len(self.flows[self.view-1])>0:
                 image = self.flows[self.view-1][self.currentZ]
             if self.view>2:
                 self.img.setImage(image, autoLevels=False, lut=self.bwr)
@@ -939,17 +939,18 @@ class MainW(QtGui.QMainWindow):
             self.current_point_set = np.array(self.current_point_set)
             while len(self.strokes) > 0:
                 self.remove_stroke(delete_points=False)
-            col_rand = np.random.randint(1000)
-            color = self.colormap[col_rand,:3]
-            median = self.add_mask(points=self.current_point_set, color=color)
-            if median is not None:
-                self.toggle_mask_ops()
-                self.cellcolors.append(color)
-                self.ncells+=1
-                self.ismanual = np.append(self.ismanual, True)
-                if self.NZ==1:
-                    # only save after each cell if single image
-                    io._save_sets(self)
+            if len(self.current_point_set) > 8:
+                col_rand = np.random.randint(1000)
+                color = self.colormap[col_rand,:3]
+                median = self.add_mask(points=self.current_point_set, color=color)
+                if median is not None:
+                    self.toggle_mask_ops()
+                    self.cellcolors.append(color)
+                    self.ncells+=1
+                    self.ismanual = np.append(self.ismanual, True)
+                    if self.NZ==1:
+                        # only save after each cell if single image
+                        io._save_sets(self)
             self.current_stroke = []
             self.strokes = []
             self.current_point_set = []
